@@ -1,6 +1,6 @@
 package Opsview::REST::APICaller;
 {
-  $Opsview::REST::APICaller::VERSION = '0.011';
+  $Opsview::REST::APICaller::VERSION = '0.012';
 }
 
 use Moo::Role;
@@ -55,7 +55,11 @@ sub post {
     my ($self, $method, $data) = @_;
 
     my $stuff = { headers => $self->headers };
-    $stuff->{content} = $self->json->encode($data) if defined $data;
+    if (defined $data) {
+        $stuff->{content} = $self->json->encode($data);
+    } else {
+        $stuff->{headers}->{'Content-Length'} = '0';
+    }
 
     my $r = $self->ua->post($self->base_url . $method, $stuff);
     croak $self->_errmsg($r) unless $r->{success};
